const path = require('path');
const babel = require('@babel/core');
const plugin = require('./index');

/**
 * Get snapshot helper
 *
 * @param {string} string The source code
 * @param {Object} options The options
 */
function snapshot(string, options) {
    const { code } = babel.transformSync(string, {
        filename: path.resolve(__dirname, 'index.js'),
        babelrc: false,
        presets: [],
        plugins: [[plugin, options]],
    });

    expect(code).toMatchSnapshot();
}

test('Import declaration', () => {
    snapshot(`
        import logosvg from './fixtures/logo.svg';
        import logopng from './fixtures/logo.png';
    `);
});

test('Require declaration', () => {
    snapshot(`
        const logosvg = require('./fixtures/logo.svg');
        const logopng = require('./fixtures/logo.png');
    `);
});

test('Import declaration w/ options', () => {
    snapshot(
        `
        import fonteot from './fixtures/font.eot';
        import fontsvg from './fixtures/font.svg';
        import fontttf from './fixtures/font.ttf';
        import fontwoff from './fixtures/font.woff';
        import fontwoff2 from './fixtures/font.woff2';
    `,
        { extensions: ['.eot', '.svg', '.ttf', '.woff', 'woff2'] }
    );
});

test('Require declaration w/ options', () => {
    snapshot(
        `
        const fonteot = require('./fixtures/font.eot');
        const fontsvg = require('./fixtures/font.svg');
        const fontttf = require('./fixtures/font.ttf');
        const fontwoff = require('./fixtures/font.woff');
        const fontwoff2 = require('./fixtures/font.woff2');
    `,
        { extensions: ['.eot', '.svg', '.ttf', '.woff', 'woff2'] }
    );
});

test('Import declaration w/ options empty extensions', () => {
    snapshot(
        `
        import logosvg from './fixtures/logo.svg';
        import logopng from './fixtures/logo.png';
    `,
        { extensions: [] }
    );
});

test('Require declaration w/ options empty extensions', () => {
    snapshot(
        `
        const logosvg = require('./fixtures/logo.svg');
        const logopng = require('./fixtures/logo.png');
    `,
        { extensions: [] }
    );
});
